==> eiffelstudio-18.01.10.1424.tar: F_code/C6/xm272.h <==

#ifndef _C6_xm272_
#define _C6_xm272_

#ifdef __cplusplus
extern "C" {
#endif

extern void F330_4997(EIF_REFERENCE);
extern void F330_4998(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5001(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F330_5003(EIF_REFERENCE);
extern void F330_5004(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5005(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F330_5007(EIF_REFERENCE);
extern EIF_BOOLEAN F330_5008(EIF_REFERENCE);
extern EIF_REFERENCE F330_5010(EIF_REFERENCE);
extern EIF_REFERENCE F330_5011(EIF_REFERENCE);
extern EIF_REFERENCE F330_5012(EIF_REFERENCE);
extern EIF_REFERENCE F330_5013(EIF_REFERENCE);
extern EIF_REFERENCE F330_5014(EIF_REFERENCE);
extern EIF_INTEGER_32 F330_5015(EIF_REFERENCE);
extern EIF_INTEGER_32 F330_5016(EIF_REFERENCE);
extern EIF_INTEGER_32 F330_5017(EIF_REFERENCE);
extern void F330_5018(EIF_REFERENCE);
extern EIF_REFERENCE F330_5019(EIF_REFERENCE);
extern void F330_5020(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F330_5021(EIF_REFERENCE);
extern void F330_5022(EIF_REFERENCE);
extern void F330_5023(EIF_REFERENCE);
extern void F330_5024(EIF_REFERENCE);
extern void F330_5025(EIF_REFERENCE);
extern void F330_5026(EIF_REFERENCE);
extern void F330_5027(EIF_REFERENCE);
extern void F330_5028(EIF_REFERENCE);
extern void F330_5029(EIF_REFERENCE);
extern void F330_5030(EIF_REFERENCE);
extern void F330_5031(EIF_REFERENCE);
extern void F330_5032(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE, EIF_BOOLEAN);
extern void F330_5033(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5034(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5035(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5036(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5037(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5038(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5039(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5040(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5041(EIF_REFERENCE, EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5042)


extern EIF_REFERENCE F330_5042(EIF_REFERENCE);
extern EIF_REFERENCE F330_5043(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F330_5044(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_REFERENCE F330_5045(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5046(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5047(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5051(EIF_REFERENCE);
extern void F330_5052(EIF_REFERENCE);
extern EIF_CHARACTER_32 F330_5053(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5054(EIF_REFERENCE);
extern EIF_REFERENCE F330_5055(EIF_REFERENCE);
extern EIF_REFERENCE F330_5056(EIF_REFERENCE);
extern EIF_REFERENCE F330_5057(EIF_REFERENCE);
extern EIF_REFERENCE F330_5058(EIF_REFERENCE);
extern EIF_REFERENCE F330_5059(EIF_REFERENCE);
extern EIF_REFERENCE F330_5060(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_REFERENCE F330_5061(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_NATURAL_32 F330_5062(EIF_REFERENCE, EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5063)
static EIF_REFERENCE F330_5063_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5063(EIF_REFERENCE);
extern EIF_BOOLEAN F330_5064(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5065(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5066(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5067(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5068(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5069(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5070(EIF_REFERENCE, EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5072)
static EIF_REFERENCE F330_5072_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5072(EIF_REFERENCE);
extern EIF_REFERENCE F330_5073(EIF_REFERENCE);
extern EIF_REFERENCE F330_5074(EIF_REFERENCE);
extern EIF_REFERENCE F330_5075(EIF_REFERENCE);
extern EIF_REFERENCE F330_5076(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5077)


extern EIF_REFERENCE F330_5077(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5078)


extern EIF_REFERENCE F330_5078(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5079)


extern EIF_REFERENCE F330_5079(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5080)


extern EIF_REFERENCE F330_5080(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5081)


extern EIF_REFERENCE F330_5081(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5083)


extern EIF_REFERENCE F330_5083(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5084)
static EIF_REFERENCE F330_5084_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5084(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5085)
static EIF_REFERENCE F330_5085_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5085(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5086)
static EIF_REFERENCE F330_5086_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5086(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5087)
static EIF_REFERENCE F330_5087_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5087(EIF_REFERENCE);
RTOSHF (EIF_NATURAL_32,5088)
static EIF_NATURAL_32 F330_5088_body(EIF_REFERENCE);
extern EIF_NATURAL_32 F330_5088(EIF_REFERENCE);
extern void EIF_Minit272(void);
extern void F293_4744(EIF_REFERENCE);
extern EIF_REFERENCE F1380_12617(EIF_REFERENCE);
extern void F1382_12737(EIF_REFERENCE, EIF_INTEGER_32);
extern EIF_NATURAL_32 F1369_12348(EIF_REFERENCE);
extern void F1373_12448(EIF_REFERENCE, EIF_NATURAL_32);
extern EIF_REFERENCE F1382_12718(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F574_6181(EIF_REFERENCE);
extern void F292_4736(EIF_REFERENCE, EIF_BOOLEAN);
extern void F1148_10442(EIF_REFERENCE);
extern EIF_REFERENCE F1369_12337(EIF_REFERENCE);
extern void F293_4750(EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32);
extern void F1382_12726(EIF_REFERENCE, EIF_NATURAL_32);
extern void F292_4737(EIF_REFERENCE, EIF_BOOLEAN);
extern EIF_REFERENCE F1150_10477(EIF_REFERENCE);
extern EIF_BOOLEAN F1369_12308(EIF_REFERENCE);
extern void F1148_10425(EIF_REFERENCE, EIF_REFERENCE);
extern void F1382_12730(EIF_REFERENCE, EIF_CHARACTER_32);
extern void F1380_12603(EIF_REFERENCE, EIF_INTEGER_32);
extern void F335_5137(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_CHARACTER_32 F1321_12105(EIF_REFERENCE);
extern EIF_BOOLEAN F1380_12634(EIF_REFERENCE);
extern void F1369_12277(EIF_REFERENCE);
extern void F292_4738(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1321_12115(EIF_REFERENCE);
extern EIF_REFERENCE F1369_12330(EIF_REFERENCE);
extern void F1382_12715(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1324_12156(EIF_REFERENCE);
extern EIF_BOOLEAN F1380_12627(EIF_REFERENCE, EIF_REFERENCE);
extern void F1382_12719(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F86_2167(EIF_REFERENCE);
extern void F1380_12605(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1321_12100(EIF_REFERENCE);
extern EIF_NATURAL_32 F293_4762(EIF_REFERENCE);
extern void F293_4749(EIF_REFERENCE, EIF_INTEGER_32);
extern EIF_INTEGER_32 F1380_12614(EIF_REFERENCE, EIF_CHARACTER_32, EIF_INTEGER_32);
extern void F1382_12744(EIF_REFERENCE);
extern EIF_BOOLEAN F1369_12322(EIF_REFERENCE, EIF_REFERENCE);
extern void F1149_10455(EIF_REFERENCE);
extern void F1148_10441(EIF_REFERENCE);
extern void F1150_10471(EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32, EIF_INTEGER_32);
extern void F292_4739(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_CHARACTER_32 F1321_12107(EIF_REFERENCE);
extern void F1149_10464(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1369_12319(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1382_12762(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
extern EIF_REFERENCE F1369_12336(EIF_REFERENCE);
extern void F1148_10440(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
RTOSHF(EIF_REFERENCE,2167)
extern char *(*R4982[])();
extern char *(*R4983[])();
extern char *(*R9919[])();
extern char *(*R9897[])();
extern char *(*R5338[])();
extern char *(*R4581[])();
extern char *(*R4493[])();
extern char *(*R4496[])();
extern char *(*R4497[])();
extern char *(*R4498[])();
extern char *(*R4574[])();
extern char *(*R4575[])();
extern char *(*R4577[])();
extern char *(*R4578[])();
extern char *(*R4579[])();
extern char *(*R9883[])();
extern char *(*R9882[])();
extern char *(*R9960[])();
extern char *(*R4580[])();
extern char *(*R9925[])();
extern char *(*R4973[])();
extern char *(*R4974[])();
extern char *(*R4975[])();
extern char *(*R4976[])();
extern char *(*R4977[])();
extern char *(*R4978[])();
extern char *(*R4979[])();
extern char *(*R4508[])();
extern char *(*R4980[])();
extern char *(*R4981[])();
extern long O10141[];
extern long O4523[];
extern long O4524[];

#ifdef __cplusplus
}
#endif

#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C6/xm272.h <==

#ifndef _C6_xm272_
#define _C6_xm272_

#ifdef __cplusplus
extern "C" {
#endif

extern void F330_4997(EIF_REFERENCE);
extern void F330_4998(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5001(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F330_5003(EIF_REFERENCE);
extern void F330_5004(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5005(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F330_5007(EIF_REFERENCE);
extern EIF_BOOLEAN F330_5008(EIF_REFERENCE);
extern EIF_REFERENCE F330_5010(EIF_REFERENCE);
extern EIF_REFERENCE F330_5011(EIF_REFERENCE);
extern EIF_REFERENCE F330_5012(EIF_REFERENCE);
extern EIF_REFERENCE F330_5013(EIF_REFERENCE);
extern EIF_REFERENCE F330_5014(EIF_REFERENCE);
extern EIF_INTEGER_32 F330_5015(EIF_REFERENCE);
extern EIF_INTEGER_32 F330_5016(EIF_REFERENCE);
extern EIF_INTEGER_32 F330_5017(EIF_REFERENCE);
extern void F330_5018(EIF_REFERENCE);
extern EIF_REFERENCE F330_5019(EIF_REFERENCE);
extern void F330_5020(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F330_5021(EIF_REFERENCE);
extern void F330_5022(EIF_REFERENCE);
extern void F330_5023(EIF_REFERENCE);
extern void F330_5024(EIF_REFERENCE);
extern void F330_5025(EIF_REFERENCE);
extern void F330_5026(EIF_REFERENCE);
extern void F330_5027(EIF_REFERENCE);
extern void F330_5028(EIF_REFERENCE);
extern void F330_5029(EIF_REFERENCE);
extern void F330_5030(EIF_REFERENCE);
extern void F330_5031(EIF_REFERENCE);
extern void F330_5032(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE, EIF_BOOLEAN);
extern void F330_5033(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5034(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5035(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5036(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5037(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5038(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5039(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5040(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5041(EIF_REFERENCE, EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5042)


extern EIF_REFERENCE F330_5042(EIF_REFERENCE);
extern EIF_REFERENCE F330_5043(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F330_5044(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_REFERENCE F330_5045(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5046(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5047(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5051(EIF_REFERENCE);
extern void F330_5052(EIF_REFERENCE);
extern EIF_CHARACTER_32 F330_5053(EIF_REFERENCE, EIF_REFERENCE);
extern void F330_5054(EIF_REFERENCE);
extern EIF_REFERENCE F330_5055(EIF_REFERENCE);
extern EIF_REFERENCE F330_5056(EIF_REFERENCE);
extern EIF_REFERENCE F330_5057(EIF_REFERENCE);
extern EIF_REFERENCE F330_5058(EIF_REFERENCE);
extern EIF_REFERENCE F330_5059(EIF_REFERENCE);
extern EIF_REFERENCE F330_5060(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_REFERENCE F330_5061(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_NATURAL_32 F330_5062(EIF_REFERENCE, EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5063)
static EIF_REFERENCE F330_5063_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5063(EIF_REFERENCE);
extern EIF_BOOLEAN F330_5064(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5065(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5066(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5067(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5068(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5069(EIF_REFERENCE, EIF_CHARACTER_32);
extern EIF_BOOLEAN F330_5070(EIF_REFERENCE, EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5072)
static EIF_REFERENCE F330_5072_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5072(EIF_REFERENCE);
extern EIF_REFERENCE F330_5073(EIF_REFERENCE);
extern EIF_REFERENCE F330_5074(EIF_REFERENCE);
extern EIF_REFERENCE F330_5075(EIF_REFERENCE);
extern EIF_REFERENCE F330_5076(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5077)


extern EIF_REFERENCE F330_5077(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5078)


extern EIF_REFERENCE F330_5078(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5079)


extern EIF_REFERENCE F330_5079(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5080)


extern EIF_REFERENCE F330_5080(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5081)


extern EIF_REFERENCE F330_5081(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 5083)


extern EIF_REFERENCE F330_5083(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5084)
static EIF_REFERENCE F330_5084_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5084(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5085)
static EIF_REFERENCE F330_5085_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5085(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5086)
static EIF_REFERENCE F330_5086_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5086(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,5087)
static EIF_REFERENCE F330_5087_body(EIF_REFERENCE);
extern EIF_REFERENCE F330_5087(EIF_REFERENCE);
RTOSHF (EIF_NATURAL_32,5088)
static EIF_NATURAL_32 F330_5088_body(EIF_REFERENCE);
extern EIF_NATURAL_32 F330_5088(EIF_REFERENCE);
extern void EIF_Minit272(void);
extern void F1149_10468(EIF_REFERENCE, EIF_REFERENCE);
extern void F1148_10445(EIF_REFERENCE);
extern EIF_BOOLEAN F1369_12323(EIF_REFERENCE, EIF_REFERENCE);
extern void F1374_12538(EIF_REFERENCE, EIF_CHARACTER_32);
extern void F1374_12545(EIF_REFERENCE, EIF_INTEGER_32);
extern void F290_4724(EIF_REFERENCE);
extern void F1371_12381(EIF_REFERENCE, EIF_NATURAL_32);
extern void F1149_10459(EIF_REFERENCE);
extern void F1372_12413(EIF_REFERENCE, EIF_REFERENCE);
extern void F289_4717(EIF_REFERENCE, EIF_BOOLEAN);
extern void F289_4716(EIF_REFERENCE, EIF_BOOLEAN);
extern EIF_REFERENCE F1369_12340(EIF_REFERENCE);
extern EIF_BOOLEAN F572_6181(EIF_REFERENCE);
extern void F1374_12534(EIF_REFERENCE, EIF_NATURAL_32);
extern EIF_CHARACTER_32 F1321_12111(EIF_REFERENCE);
extern void F1148_10446(EIF_REFERENCE);
extern void F1374_12552(EIF_REFERENCE);
extern EIF_REFERENCE F1369_12334(EIF_REFERENCE);
extern EIF_NATURAL_32 F1369_12352(EIF_REFERENCE);
extern void F335_5137(EIF_REFERENCE, EIF_REFERENCE);
extern void F1150_10475(EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32, EIF_INTEGER_32);
extern void F290_4730(EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32);
extern void F1148_10444(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
extern EIF_REFERENCE F1372_12425(EIF_REFERENCE);
extern void F1148_10429(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1374_12526(EIF_REFERENCE, EIF_REFERENCE);
extern void F1372_12412(EIF_REFERENCE, EIF_CHARACTER_32, EIF_INTEGER_32);
extern void F289_4718(EIF_REFERENCE, EIF_REFERENCE);
extern void F1372_12411(EIF_REFERENCE, EIF_INTEGER_32);
extern EIF_CHARACTER_32 F1321_12109(EIF_REFERENCE);
extern void F290_4729(EIF_REFERENCE, EIF_INTEGER_32);
extern EIF_REFERENCE F1369_12341(EIF_REFERENCE);
extern EIF_BOOLEAN F1369_12312(EIF_REFERENCE);
extern EIF_REFERENCE F86_2167(EIF_REFERENCE);
extern EIF_REFERENCE F1150_10481(EIF_REFERENCE);
extern EIF_INTEGER_32 F1372_12422(EIF_REFERENCE, EIF_CHARACTER_32, EIF_INTEGER_32);
extern void F1369_12281(EIF_REFERENCE);
extern EIF_BOOLEAN F1321_12119(EIF_REFERENCE);
extern void F289_4719(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1374_12570(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
extern EIF_BOOLEAN F1324_12160(EIF_REFERENCE);
extern EIF_NATURAL_32 F290_4742(EIF_REFERENCE);
extern EIF_BOOLEAN F1369_12326(EIF_REFERENCE, EIF_REFERENCE);
extern void F1374_12523(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1372_12435(EIF_REFERENCE, EIF_REFERENCE);
extern void F1374_12527(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1372_12442(EIF_REFERENCE);
RTOSHF(EIF_REFERENCE,2167)
extern char *(*R4982[])();
extern char *(*R4983[])();
extern char *(*R9901[])();
extern char *(*R5338[])();
extern char *(*R4493[])();
extern char *(*R4496[])();
extern char *(*R4497[])();
extern char *(*R4498[])();
extern char *(*R4574[])();
extern char *(*R4575[])();
extern char *(*R4577[])();
extern char *(*R4578[])();
extern char *(*R4579[])();
extern char *(*R9886[])();
extern char *(*R9887[])();
extern char *(*R9964[])();
extern char *(*R9923[])();
extern char *(*R4580[])();
extern char *(*R4581[])();
extern char *(*R9929[])();
extern char *(*R4973[])();
extern char *(*R4974[])();
extern char *(*R4975[])();
extern char *(*R4976[])();
extern char *(*R4977[])();
extern char *(*R4978[])();
extern char *(*R4979[])();
extern char *(*R4508[])();
extern char *(*R4980[])();
extern char *(*R4981[])();
extern long O10040[];
extern long O4523[];
extern long O4524[];

#ifdef __cplusplus
}
#endif

#endif
